[svn-commits] sruffell: linux/trunk r7576 - /linux/trunk/drivers/dahdi/wcb4xxp/

SVN commits to the Digium repositories svn-commits at lists.digium.com
Thu Nov 12 15:48:21 CST 2009


Author: sruffell
Date: Thu Nov 12 15:48:17 2009
New Revision: 7576

URL: http://svnview.digium.com/svn/dahdi?view=rev&rev=7576
Log:
wcb4xxp: More hw ids for HFC-4S & HFC-8S

Solves a typo in Junghanns 8 ports card hw id & adds more hardware ids
(Beronet mainly). All tested ok in asterisk-es group.

(issue #15446)
Reported by: Odicha
Patches:
      wcb4xxp dahdi-linux.patch uploaded by Odicha (license 700)

Modified:
    linux/trunk/drivers/dahdi/wcb4xxp/base.c
    linux/trunk/drivers/dahdi/wcb4xxp/wcb4xxp.h

Modified: linux/trunk/drivers/dahdi/wcb4xxp/base.c
URL: http://svnview.digium.com/svn/dahdi/linux/trunk/drivers/dahdi/wcb4xxp/base.c?view=diff&rev=7576&r1=7575&r2=7576
==============================================================================
--- linux/trunk/drivers/dahdi/wcb4xxp/wcb4xxp.h (original)
+++ linux/trunk/drivers/dahdi/wcb4xxp/wcb4xxp.h Thu Nov 12 15:48:17 2009
@@ -425,6 +425,7 @@
 	BN2S0,		/* BeroNet BN2S0			*/
 	BN4S0,		/* Beronet BN4S0			*/
 	BN8S0		/* BeroNet BN8S0			*/
+	QUADBRI_EVAL	/* HFC-4S CCD Eval. Board		*/
 	};
 
 /* This structure exists one per card */




More information about the svn-commits mailing list
--- linux/trunk/drivers/dahdi/wcb4xxp/base.c (original)
+++ linux/trunk/drivers/dahdi/wcb4xxp/base.c Thu Nov 12 15:48:17 2009
@@ -137,6 +137,8 @@
 static struct devtype hfc2s_BN = {"BeroNet BN2S0", .ports = 2, .card_type = BN2S0 };
 static struct devtype hfc4s_BN = {"BeroNet BN4S0", .ports = 4, .card_type = BN4S0 };
 static struct devtype hfc8s_BN = {"BeroNet BN8S0", .ports = 8, .card_type = BN8S0 };
+static struct devtype hfc4s_EV = {"CCD HFC-4S Eval. Board", .ports = 4,
+					.card_type = QUADBRI_EVAL };
  
 #define CARD_HAS_EC(card) ((card)->card_type == B410P)
 
@@ -1828,13 +1830,14 @@
 	b4xxp_setreg8(b4, R_SCI_MSK, 0x00);	/* mask off all S/T interrupts */
 	b4xxp_setreg8(b4, R_IRQMSK_MISC, 0x00);	/* nothing else can generate an interrupt */
 
-/*
- * set up the clock controller
- * B410P has a 24.576MHz crystal, so the PCM clock is 2x the incoming clock.
- * Other cards have a 49.152Mhz crystal, so the PCM clock equals incoming clock.
- */
-
-	if (b4->card_type == B410P)
+	/*
+	 * set up the clock controller B410P & Cologne Eval Board have a
+	 * 24.576MHz crystal, so the PCM clock is 2x the incoming clock.
+	 * Other cards have a 49.152Mhz crystal, so the PCM clock equals
+	 * incoming clock.
+	 */
+
+	if ((b4->card_type == B410P) || (b4->card_type == QUADBRI_EVAL))
 		b4xxp_setreg8(b4, R_BRG_PCM_CFG, 0x02);
 	else
 		b4xxp_setreg8(b4, R_BRG_PCM_CFG, V_PCM_CLK);
@@ -2876,15 +2879,19 @@
 static struct pci_device_id b4xx_ids[] __devinitdata =
 {
 	{ 0xd161, 0xb410, PCI_ANY_ID, PCI_ANY_ID, 0, 0, (unsigned long)&wcb4xxp },
-	{ 0x1397, 0x16b8, 0x1397, 0xe552, 0, 0, (unsigned long)&hfc8s },
+	{ 0x1397, 0x16b8, 0x1397, 0xb552, 0, 0, (unsigned long)&hfc8s },
 	{ 0x1397, 0x08b4, 0x1397, 0xb520, 0, 0, (unsigned long)&hfc4s },
 	{ 0x1397, 0x08b4, 0x1397, 0xb556, 0, 0, (unsigned long)&hfc2s },
 	{ 0x1397, 0x08b4, 0x1397, 0xe884, 0, 0, (unsigned long)&hfc2s_OV },
 	{ 0x1397, 0x08b4, 0x1397, 0xe888, 0, 0, (unsigned long)&hfc4s_OV },
 	{ 0x1397, 0x16b8, 0x1397, 0xe998, 0, 0, (unsigned long)&hfc8s_OV },
 	{ 0x1397, 0x08b4, 0x1397, 0xb566, 0, 0, (unsigned long)&hfc2s_BN },
+	{ 0x1397, 0x08b4, 0x1397, 0xb761, 0, 0, (unsigned long)&hfc2s_BN },
 	{ 0x1397, 0x08b4, 0x1397, 0xb560, 0, 0, (unsigned long)&hfc4s_BN },
+	{ 0x1397, 0x08b4, 0x1397, 0xb550, 0, 0, (unsigned long)&hfc4s_BN },
 	{ 0x1397, 0x16b8, 0x1397, 0xb562, 0, 0, (unsigned long)&hfc8s_BN },
+	{ 0x1397, 0x16b8, 0x1397, 0xb56b, 0, 0, (unsigned long)&hfc8s_BN },
+	{ 0x1397, 0x08b4, 0x1397, 0x08b4, 0, 0, (unsigned long)&hfc4s_EV },
 	{0, }
 
 };

Modified: linux/trunk/drivers/dahdi/wcb4xxp/wcb4xxp.h
URL: http://svnview.digium.com/svn/dahdi/linux/trunk/drivers/dahdi/wcb4xxp/wcb4xxp.h?view=diff&rev=7576&r1=7575&r2=7576
==============================================================================